You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by dm...@apache.org on 2017/04/11 01:38:50 UTC

[50/50] [abbrv] ignite git commit: IGNITE-1192: finished implementation, working on the test

IGNITE-1192: finished implementation, working on the test


Project: http://git-wip-us.apache.org/repos/asf/ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/ignite/commit/362700c6
Tree: http://git-wip-us.apache.org/repos/asf/ignite/tree/362700c6
Diff: http://git-wip-us.apache.org/repos/asf/ignite/diff/362700c6

Branch: refs/heads/ignite-1192
Commit: 362700c6ae0342f356b0a66be80065fe945743f6
Parents: 2ab0999
Author: Denis Magda <dm...@gridgain.com>
Authored: Mon Apr 10 18:37:45 2017 -0700
Committer: Denis Magda <dm...@gridgain.com>
Committed: Mon Apr 10 18:37:45 2017 -0700

----------------------------------------------------------------------
 assembly/libs/README.txt                        |   2 +-
 bin/ignite.bat                                  |   4 +-
 bin/ignite.sh                                   |   4 +-
 bin/ignitevisorcmd.bat                          |   4 +-
 bin/ignitevisorcmd.sh                           |   4 +-
 bin/include/functions.sh                        |   2 +-
 bin/include/service.sh                          |   2 +-
 config/example-kube.xml                         |   4 +-
 dev-tools/gradlew                               |   4 +-
 examples/config/example-cache.xml               |   4 +-
 examples/config/example-default.xml             |   4 +-
 examples/config/filesystem/example-igfs.xml     |   4 +-
 examples/config/spark/example-shared-rdd.xml    |   4 +-
 ipc/shmem/README.txt                            |   2 +-
 ipc/shmem/aclocal.m4                            |  40 +--
 ipc/shmem/config.guess                          |   4 +-
 ipc/shmem/configure                             |  56 ++--
 ipc/shmem/igniteshmem/Makefile.am               |   4 +-
 ipc/shmem/igniteshmem/Makefile.in               |   4 +-
 ipc/shmem/install-sh                            |   2 +-
 ipc/shmem/ltmain.sh                             |  42 +--
 ipc/shmem/m4/libtool.m4                         |  18 +-
 ipc/shmem/m4/ltoptions.m4                       |  20 +-
 .../test/config/aop/aspectj/META-INF/aop.xml    |   2 +-
 .../bootstrap/aws/cassandra/cassandra-env.sh    |  14 +-
 .../aws/cassandra/cassandra-template.yaml       |  10 +-
 .../tests/persistence/blob/ignite-config.xml    |   4 +-
 .../tests/persistence/pojo/ignite-config.xml    |   4 +-
 .../persistence/pojo/persistence-settings-3.xml |   6 +-
 .../persistence/pojo/persistence-settings-4.xml |   6 +-
 .../persistence/primitive/ignite-config.xml     |   4 +-
 .../primitive/ignite-remote-server-config.xml   |   4 +-
 modules/platforms/cpp/DEVNOTES.txt              |   4 +-
 modules/platforms/cpp/cpp.dxg                   |  38 +--
 .../config/continuous-query-example.xml         |   2 +-
 .../odbc-example/config/example-odbc.xml        |   2 +-
 .../putget-example/config/example-cache.xml     |   2 +-
 .../query-example/config/query-example.xml      |   2 +-
 .../cpp/odbc-test/config/queries-default.xml    |   2 +-
 .../IgniteConfigurationSection.xsd              |   2 +-
 modules/platforms/dotnet/Apache.Ignite.dxg      |  44 +--
 modules/platforms/dotnet/build.ps1              |   2 +-
 .../test/resources/spring-ping-pong-partner.xml |   4 +-
 modules/spring-data/pom.xml                     |  15 +-
 .../springdata/IgniteKeyValueAdapter.java       |   2 +-
 .../ignite/springdata/repository/Query.java     |  37 +++
 .../config/EnableIgniteRepositories.java        |  12 +-
 .../IgniteRepositoryConfigurationExtension.java |  14 +
 .../repository/config/RepositoryConfig.java     |  39 +++
 .../repository/query/IgniteQuery.java           |  83 +++++
 .../repository/query/IgniteQueryGenerator.java  | 243 +++++++++++++++
 .../repository/query/IgniteRepositoryQuery.java | 306 +++++++++++++++++++
 .../support/IgniteRepositoryFactory.java        | 176 +++++++++++
 .../support/IgniteRepositoryFactoryBean.java    |  55 ++++
 .../springdata/IgniteSpringDataSelfTest.java    | 286 +++++++++++++++++
 .../springdata/IgniteSpringDataTestSuite.java   |  38 +++
 .../misc/ApplicationConfiguration.java          |  59 ++++
 .../ignite/springdata/misc/FirstRepository.java |  92 ++++++
 .../apache/ignite/springdata/misc/Person.java   |  75 +++++
 .../springdata/misc/SecondRepository.java       |  40 +++
 modules/web-console/README.txt                  |   2 +-
 .../ui-grid-header/ui-grid-header.tpl.pug       |   2 +-
 .../directives/ui-ace-pojos/ui-ace-pojos.pug    |   2 +-
 .../helpers/jade/form/form-field-checkbox.pug   |   6 +-
 .../helpers/jade/form/form-field-datalist.pug   |   6 +-
 .../helpers/jade/form/form-field-dropdown.pug   |   8 +-
 .../frontend/app/helpers/jade/mixins.pug        |  52 ++--
 .../app/modules/nodes/nodes-dialog.tpl.pug      |   2 +-
 .../states/configuration/caches/node-filter.pug |   2 +-
 .../states/configuration/clusters/ssl.pug       |   8 +-
 .../states/configuration/domains/query.pug      |  10 +-
 .../states/configuration/domains/store.pug      |   4 +-
 .../modules/states/configuration/igfs/misc.pug  |   2 +-
 .../frontend/app/primitives/tooltip/index.pug   |   6 +-
 .../frontend/public/stylesheets/style.scss      |   6 +-
 .../frontend/views/configuration/caches.tpl.pug |   4 +-
 .../views/configuration/clusters.tpl.pug        |   4 +-
 .../views/configuration/domains-import.tpl.pug  |  12 +-
 .../frontend/views/configuration/igfs.tpl.pug   |   4 +-
 .../summary-project-structure.tpl.pug           |   2 +-
 .../frontend/views/settings/admin.tpl.pug       |   2 +-
 .../frontend/views/settings/profile.tpl.pug     |   6 +-
 .../web-console/frontend/views/signin.tpl.pug   |   2 +-
 .../frontend/views/sql/cache-metadata.tpl.pug   |   2 +-
 .../frontend/views/sql/chart-settings.tpl.pug   |   2 +-
 .../frontend/views/sql/paragraph-rate.tpl.pug   |   2 +-
 .../web-console/frontend/views/sql/sql.tpl.pug  |  10 +-
 .../views/templates/agent-download.tpl.pug      |   2 +-
 modules/web-console/web-agent/README.txt        |   2 +-
 .../web-agent/bin/ignite-web-agent.bat          |   2 +-
 .../web-agent/bin/ignite-web-agent.sh           |   2 +-
 .../config/benchmark-atomic-win.properties      |   2 +-
 .../config/benchmark-atomic.properties          |   2 +-
 .../config/benchmark-bin-identity.properties    |   2 +-
 .../config/benchmark-cache-load-win.properties  |   2 +-
 .../config/benchmark-cache-load.properties      |   2 +-
 .../config/benchmark-client-mode.properties     |   2 +-
 .../config/benchmark-compute-win.properties     |   2 +-
 .../config/benchmark-compute.properties         |   2 +-
 .../config/benchmark-failover.properties        |   2 +-
 .../yardstick/config/benchmark-full.properties  |   2 +-
 .../config/benchmark-multicast.properties       |   2 +-
 .../config/benchmark-put-indexed-val.properties |   2 +-
 .../benchmark-query-put-separated.properties    |   2 +-
 .../config/benchmark-query-win.properties       |   2 +-
 .../yardstick/config/benchmark-query.properties |   2 +-
 .../config/benchmark-remote-sample.properties   |   2 +-
 .../config/benchmark-remote.properties          |   2 +-
 .../config/benchmark-sample.properties          |   2 +-
 .../config/benchmark-sql-dml.properties         |   2 +-
 .../yardstick/config/benchmark-store.properties |   2 +-
 .../config/benchmark-tx-win.properties          |   2 +-
 .../yardstick/config/benchmark-tx.properties    |   2 +-
 .../yardstick/config/benchmark-win.properties   |   2 +-
 modules/yardstick/config/benchmark.properties   |   2 +-
 .../test-max-int-values-offheap.properties      |   2 +-
 .../test-max-int-values-onheap.properties       |   2 +-
 .../config/test-max-int-values-swap.properties  |   2 +-
 118 files changed, 1877 insertions(+), 323 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/assembly/libs/README.txt
----------------------------------------------------------------------
diff --git a/assembly/libs/README.txt b/assembly/libs/README.txt
index 9902e8c..ced2812 100644
--- a/assembly/libs/README.txt
+++ b/assembly/libs/README.txt
@@ -20,7 +20,7 @@ to 'libs' folder. You can create a subfolder for convenience as well.
 Importing Ignite Dependencies In Maven Project
 ------------------------------------------------
 
-If you are using Maven to manage dependencies of your project, there are two options:
+If you are using Maven to manage dependencies of your project, there are two option:
 
 1. Import fabric edition:
   - ignite-fabric (all inclusive)

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/bin/ignite.bat
----------------------------------------------------------------------
diff --git a/bin/ignite.bat b/bin/ignite.bat
index db686cc..51525bc 100644
--- a/bin/ignite.bat
+++ b/bin/ignite.bat
@@ -155,7 +155,7 @@ if "%JMX_PORT%" == "" (
 )
 
 ::
-:: JVM options. See http://java.sun.com/javase/technologies/hotspot/vmoptions.jsp for more details.
+:: JVM option. See http://java.sun.com/javase/technologies/hotspot/vmoptions.jsp for more details.
 ::
 :: ADD YOUR/CHANGE ADDITIONAL OPTIONS HERE
 ::
@@ -195,7 +195,7 @@ if %ERRORLEVEL% equ 0 (
 set ENABLE_ASSERTIONS=1
 
 ::
-:: Set '-ea' options if assertions are enabled.
+:: Set '-ea' option if assertions are enabled.
 ::
 if %ENABLE_ASSERTIONS% == 1 set JVM_OPTS=%JVM_OPTS% -ea
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/bin/ignite.sh
----------------------------------------------------------------------
diff --git a/bin/ignite.sh b/bin/ignite.sh
index efa3715..507100d 100755
--- a/bin/ignite.sh
+++ b/bin/ignite.sh
@@ -85,7 +85,7 @@ if [ "${DOCK_OPTS}" == "" ]; then
 fi
 
 #
-# JVM options. See http://java.sun.com/javase/technologies/hotspot/vmoptions.jsp for more details.
+# JVM option. See http://java.sun.com/javase/technologies/hotspot/vmoptions.jsp for more details.
 #
 # ADD YOUR/CHANGE ADDITIONAL OPTIONS HERE
 #
@@ -121,7 +121,7 @@ fi
 ENABLE_ASSERTIONS="1"
 
 #
-# Set '-ea' options if assertions are enabled.
+# Set '-ea' option if assertions are enabled.
 #
 if [ "${ENABLE_ASSERTIONS}" = "1" ]; then
     JVM_OPTS="${JVM_OPTS} -ea"

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/bin/ignitevisorcmd.bat
----------------------------------------------------------------------
diff --git a/bin/ignitevisorcmd.bat b/bin/ignitevisorcmd.bat
index 236f896..c9aff2f 100644
--- a/bin/ignitevisorcmd.bat
+++ b/bin/ignitevisorcmd.bat
@@ -114,7 +114,7 @@ if %ERRORLEVEL% neq 0 (
 )
 
 ::
-:: JVM options. See http://java.sun.com/javase/technologies/hotspot/vmoptions.jsp for more details.
+:: JVM option. See http://java.sun.com/javase/technologies/hotspot/vmoptions.jsp for more details.
 ::
 :: ADD YOUR/CHANGE ADDITIONAL OPTIONS HERE
 ::
@@ -132,7 +132,7 @@ if "%JVM_OPTS_VISOR%" == "" set JVM_OPTS_VISOR=-Xms1g -Xmx1g -XX:MaxPermSize=128
 set ENABLE_ASSERTIONS=1
 
 ::
-:: Set '-ea' options if assertions are enabled.
+:: Set '-ea' option if assertions are enabled.
 ::
 if %ENABLE_ASSERTIONS% == 1 set JVM_OPTS_VISOR=%JVM_OPTS_VISOR% -ea
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/bin/ignitevisorcmd.sh
----------------------------------------------------------------------
diff --git a/bin/ignitevisorcmd.sh b/bin/ignitevisorcmd.sh
index fe74f6a..1104231 100755
--- a/bin/ignitevisorcmd.sh
+++ b/bin/ignitevisorcmd.sh
@@ -57,7 +57,7 @@ setIgniteHome
 CP="${IGNITE_HOME}/bin/include/visor-common/*${SEP}${IGNITE_HOME}/bin/include/visorcmd/*${SEP}${IGNITE_LIBS}"
 
 #
-# JVM options. See http://java.sun.com/javase/technologies/hotspot/vmoptions.jsp for more details.
+# JVM option. See http://java.sun.com/javase/technologies/hotspot/vmoptions.jsp for more details.
 #
 # ADD YOUR/CHANGE ADDITIONAL OPTIONS HERE
 #
@@ -82,7 +82,7 @@ fi
 ENABLE_ASSERTIONS="1"
 
 #
-# Set '-ea' options if assertions are enabled.
+# Set '-ea' option if assertions are enabled.
 #
 if [ "${ENABLE_ASSERTIONS}" = "1" ]; then
     JVM_OPTS="${JVM_OPTS} -ea"

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/bin/include/functions.sh
----------------------------------------------------------------------
diff --git a/bin/include/functions.sh b/bin/include/functions.sh
index b18b150..038c78f 100755
--- a/bin/include/functions.sh
+++ b/bin/include/functions.sh
@@ -110,7 +110,7 @@ setIgniteHome() {
 
 #
 # Finds available port for JMX.
-# The function exports JMX_MON variable with Java JMX options.
+# The function exports JMX_MON variable with Java JMX option.
 #
 findAvailableJmxPort() {
     JMX_PORT=`"$JAVA" -cp "${IGNITE_LIBS}" org.apache.ignite.internal.util.portscanner.GridJmxPortFinder`

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/bin/include/service.sh
----------------------------------------------------------------------
diff --git a/bin/include/service.sh b/bin/include/service.sh
index 73beb86..e089781 100755
--- a/bin/include/service.sh
+++ b/bin/include/service.sh
@@ -51,7 +51,7 @@ case "$1" in
         # Configure Ignite environment.
         source "${SCRIPTS_HOME}/include/setenv.sh"
 
-        # Set default JVM options if they was not passed.
+        # Set default JVM option if they was not passed.
         if [ -z "$JVM_OPTS" ]; then
             JVM_OPTS="-Xms1g -Xmx1g -server -XX:+AggressiveOpts -XX:MaxPermSize=512m"
         fi

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/config/example-kube.xml
----------------------------------------------------------------------
diff --git a/config/example-kube.xml b/config/example-kube.xml
index a4fa086..8f06a68 100644
--- a/config/example-kube.xml
+++ b/config/example-kube.xml
@@ -37,8 +37,8 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
-                        instead os static IP based discovery. For information on all options refer
+                        Ignite provides several option for automatic discovery that can be used
+                        instead os static IP based discovery. For information on all option refer
                         to our documentation: http://apacheignite.readme.io/docs/cluster-config
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/dev-tools/gradlew
----------------------------------------------------------------------
diff --git a/dev-tools/gradlew b/dev-tools/gradlew
index aa08fcb..2bb2ef5 100755
--- a/dev-tools/gradlew
+++ b/dev-tools/gradlew
@@ -24,7 +24,7 @@
 ##
 ##############################################################################
 
-# Add default JVM options here. You can also use JAVA_OPTS and GRADLE_OPTS to pass JVM options to this script.
+# Add default JVM option here. You can also use JAVA_OPTS and GRADLE_OPTS to pass JVM option to this script.
 DEFAULT_JVM_OPTS=""
 
 APP_NAME="Gradle"
@@ -139,7 +139,7 @@ if [ "$cygwin" = "false" -a "$darwin" = "false" ] ; then
     fi
 fi
 
-# For Darwin, add options to specify how the application appears in the dock
+# For Darwin, add option to specify how the application appears in the dock
 if $darwin; then
     GRADLE_OPTS="$GRADLE_OPTS \"-Xdock:name=$APP_NAME\" \"-Xdock:icon=$APP_HOME/media/gradle.icns\""
 fi

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/examples/config/example-cache.xml
----------------------------------------------------------------------
diff --git a/examples/config/example-cache.xml b/examples/config/example-cache.xml
index 98e1a71..07cc7a7 100644
--- a/examples/config/example-cache.xml
+++ b/examples/config/example-cache.xml
@@ -52,8 +52,8 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
-                        instead os static IP based discovery. For information on all options refer
+                        Ignite provides several option for automatic discovery that can be used
+                        instead os static IP based discovery. For information on all option refer
                         to our documentation: http://apacheignite.readme.io/docs/cluster-config
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/examples/config/example-default.xml
----------------------------------------------------------------------
diff --git a/examples/config/example-default.xml b/examples/config/example-default.xml
index 6bd6f16..8933d40 100644
--- a/examples/config/example-default.xml
+++ b/examples/config/example-default.xml
@@ -62,8 +62,8 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
-                        instead os static IP based discovery. For information on all options refer
+                        Ignite provides several option for automatic discovery that can be used
+                        instead os static IP based discovery. For information on all option refer
                         to our documentation: http://apacheignite.readme.io/docs/cluster-config
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/examples/config/filesystem/example-igfs.xml
----------------------------------------------------------------------
diff --git a/examples/config/filesystem/example-igfs.xml b/examples/config/filesystem/example-igfs.xml
index 2236821..fcb4a64 100644
--- a/examples/config/filesystem/example-igfs.xml
+++ b/examples/config/filesystem/example-igfs.xml
@@ -100,8 +100,8 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignition provides several options for automatic discovery that can be used
-                        instead os static IP based discovery. For information on all options refer
+                        Ignition provides several option for automatic discovery that can be used
+                        instead os static IP based discovery. For information on all option refer
                         to our documentation: http://apacheignite.readme.io/docs/cluster-config
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/examples/config/spark/example-shared-rdd.xml
----------------------------------------------------------------------
diff --git a/examples/config/spark/example-shared-rdd.xml b/examples/config/spark/example-shared-rdd.xml
index 83de6a3..1918eee 100644
--- a/examples/config/spark/example-shared-rdd.xml
+++ b/examples/config/spark/example-shared-rdd.xml
@@ -62,8 +62,8 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
-                        instead os static IP based discovery. For information on all options refer
+                        Ignite provides several option for automatic discovery that can be used
+                        instead os static IP based discovery. For information on all option refer
                         to our documentation: http://apacheignite.readme.io/docs/cluster-config
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/ipc/shmem/README.txt
----------------------------------------------------------------------
diff --git a/ipc/shmem/README.txt b/ipc/shmem/README.txt
index e11360b..e1770d5 100644
--- a/ipc/shmem/README.txt
+++ b/ipc/shmem/README.txt
@@ -15,7 +15,7 @@ You can also do
 
     ./configure --help
 
-to see all available command line options. Once the configure script finishes, you can run a make:
+to see all available command line option. Once the configure script finishes, you can run a make:
 
     make install
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/ipc/shmem/aclocal.m4
----------------------------------------------------------------------
diff --git a/ipc/shmem/aclocal.m4 b/ipc/shmem/aclocal.m4
index e89e1c6..3bdf386 100644
--- a/ipc/shmem/aclocal.m4
+++ b/ipc/shmem/aclocal.m4
@@ -201,7 +201,7 @@ m4_require([_LT_CMD_GLOBAL_SYMBOLS])dnl
 m4_require([_LT_WITH_SYSROOT])dnl
 
 _LT_CONFIG_LIBTOOL_INIT([
-# See if we are running on zsh, and set the options which allow our
+# See if we are running on zsh, and set the option which allow our
 # commands through without removal of \ escapes INIT.
 if test -n "\${ZSH_VERSION+set}" ; then
    setopt NO_GLOB_SUBST
@@ -721,7 +721,7 @@ m4_defun([_LT_CONFIG],
 _LT_CONFIG_SAVE_COMMANDS([
   m4_define([_LT_TAG], m4_if([$1], [], [C], [$1]))dnl
   m4_if(_LT_TAG, [C], [
-    # See if we are running on zsh, and set the options which allow our
+    # See if we are running on zsh, and set the option which allow our
     # commands through without removal of \ escapes.
     if test -n "${ZSH_VERSION+set}" ; then
       setopt NO_GLOB_SUBST
@@ -1987,7 +1987,7 @@ dnl AC_DEFUN([AC_LIBTOOL_DLOPEN_SELF], [])
 
 # _LT_COMPILER_C_O([TAGNAME])
 # ---------------------------
-# Check to see if options -c and -o are simultaneously supported by compiler.
+# Check to see if option -c and -o are simultaneously supported by compiler.
 # This macro does not hard code the compiler like AC_PROG_CC_C_O.
 m4_defun([_LT_COMPILER_C_O],
 [m4_require([_LT_DECL_SED])dnl
@@ -2037,7 +2037,7 @@ AC_CACHE_CHECK([if $compiler supports -c -o file.$ac_objext],
    $RM conftest*
 ])
 _LT_TAGDECL([compiler_c_o], [lt_cv_prog_compiler_c_o], [1],
-	[Does compiler simultaneously support -c and -o options?])
+	[Does compiler simultaneously support -c and -o option?])
 ])# _LT_COMPILER_C_O
 
 
@@ -3946,7 +3946,7 @@ m4_if([$1], [CXX], [
       _LT_TAGVAR(lt_prog_compiler_static, $1)=
       ;;
     interix[[3-9]]*)
-      # Interix 3.x gcc -fpic/-fPIC options generate broken code.
+      # Interix 3.x gcc -fpic/-fPIC option generate broken code.
       # Instead, we relocate shared libraries at runtime.
       ;;
     sysv4*MP*)
@@ -4277,7 +4277,7 @@ m4_if([$1], [CXX], [
       ;;
 
     interix[[3-9]]*)
-      # Interix 3.x gcc -fpic/-fPIC options generate broken code.
+      # Interix 3.x gcc -fpic/-fPIC option generate broken code.
       # Instead, we relocate shared libraries at runtime.
       ;;
 
@@ -5484,7 +5484,7 @@ _LT_EOF
       case $host_os in
       solaris2.[[0-5]] | solaris2.[[0-5]].*) ;;
       *)
-	# The compiler driver will combine and reorder linker options,
+	# The compiler driver will combine and reorder linker option,
 	# but understands `-z linker_flag'.  GCC discards it without `$wl',
 	# but is careful enough not to reorder.
 	# Supported since Solaris 2.6 (maybe 2.5.1?)
@@ -6731,7 +6731,7 @@ if test "$_lt_caught_CXX_error" != yes; then
 	    case $host_os in
 	      solaris2.[[0-5]] | solaris2.[[0-5]].*) ;;
 	      *)
-		# The compiler driver will combine and reorder linker options,
+		# The compiler driver will combine and reorder linker option,
 		# but understands `-z linker_flag'.
 	        # Supported since Solaris 2.6 (maybe 2.5.1?)
 		_LT_TAGVAR(whole_archive_flag_spec, $1)='-z allextract$convenience -z defaultextract'
@@ -7710,7 +7710,7 @@ test -z "$SED" && SED=sed
 Xsed="$SED -e 1s/^X//"
 _LT_DECL([], [SED], [1], [A sed program that does not truncate output])
 _LT_DECL([], [Xsed], ["\$SED -e 1s/^X//"],
-    [Sed that helps us avoid accidentally triggering echo(1) options like -n])
+    [Sed that helps us avoid accidentally triggering echo(1) option like -n])
 ])# _LT_DECL_SED
 
 m4_ifndef([AC_PROG_SED], [
@@ -8034,7 +8034,7 @@ m4_define([_LT_IF_OPTION],
 
 # _LT_UNLESS_OPTIONS(MACRO-NAME, OPTION-LIST, IF-NOT-SET)
 # -------------------------------------------------------
-# Execute IF-NOT-SET unless all options in OPTION-LIST for MACRO-NAME
+# Execute IF-NOT-SET unless all option in OPTION-LIST for MACRO-NAME
 # are set.
 m4_define([_LT_UNLESS_OPTIONS],
 [m4_foreach([_LT_Option], m4_split(m4_normalize([$2])),
@@ -8047,25 +8047,25 @@ m4_ifdef([$0_found], [m4_undefine([$0_found])], [$3
 
 # _LT_SET_OPTIONS(MACRO-NAME, OPTION-LIST)
 # ----------------------------------------
-# OPTION-LIST is a space-separated list of Libtool options associated
+# OPTION-LIST is a space-separated list of Libtool option associated
 # with MACRO-NAME.  If any OPTION has a matching handler declared with
 # LT_OPTION_DEFINE, dispatch to that macro; otherwise complain about
 # the unknown option and exit.
 m4_defun([_LT_SET_OPTIONS],
-[# Set options
+[# Set option
 m4_foreach([_LT_Option], m4_split(m4_normalize([$2])),
     [_LT_SET_OPTION([$1], _LT_Option)])
 
 m4_if([$1],[LT_INIT],[
   dnl
-  dnl Simply set some default values (i.e off) if boolean options were not
+  dnl Simply set some default values (i.e off) if boolean option were not
   dnl specified:
   _LT_UNLESS_OPTIONS([LT_INIT], [dlopen], [enable_dlopen=no
   ])
   _LT_UNLESS_OPTIONS([LT_INIT], [win32-dll], [enable_win32_dll=no
   ])
   dnl
-  dnl If no reference was made to various pairs of opposing options, then
+  dnl If no reference was made to various pairs of opposing option, then
   dnl we run the default mode handler for the pair.  For example, if neither
   dnl `shared' nor `disable-shared' was passed, we enable building of shared
   dnl archives by default:
@@ -8147,7 +8147,7 @@ dnl AC_DEFUN([AC_LIBTOOL_WIN32_DLL], [])
 # _LT_ENABLE_SHARED([DEFAULT])
 # ----------------------------
 # implement the --enable-shared flag, and supports the `shared' and
-# `disable-shared' LT_INIT options.
+# `disable-shared' LT_INIT option.
 # DEFAULT is either `yes' or `no'.  If omitted, it defaults to `yes'.
 m4_define([_LT_ENABLE_SHARED],
 [m4_define([_LT_ENABLE_SHARED_DEFAULT], [m4_if($1, no, no, yes)])dnl
@@ -8201,7 +8201,7 @@ dnl AC_DEFUN([AM_DISABLE_SHARED], [])
 # _LT_ENABLE_STATIC([DEFAULT])
 # ----------------------------
 # implement the --enable-static flag, and support the `static' and
-# `disable-static' LT_INIT options.
+# `disable-static' LT_INIT option.
 # DEFAULT is either `yes' or `no'.  If omitted, it defaults to `yes'.
 m4_define([_LT_ENABLE_STATIC],
 [m4_define([_LT_ENABLE_STATIC_DEFAULT], [m4_if($1, no, no, yes)])dnl
@@ -8255,7 +8255,7 @@ dnl AC_DEFUN([AM_DISABLE_STATIC], [])
 # _LT_ENABLE_FAST_INSTALL([DEFAULT])
 # ----------------------------------
 # implement the --enable-fast-install flag, and support the `fast-install'
-# and `disable-fast-install' LT_INIT options.
+# and `disable-fast-install' LT_INIT option.
 # DEFAULT is either `yes' or `no'.  If omitted, it defaults to `yes'.
 m4_define([_LT_ENABLE_FAST_INSTALL],
 [m4_define([_LT_ENABLE_FAST_INSTALL_DEFAULT], [m4_if($1, no, no, yes)])dnl
@@ -8311,7 +8311,7 @@ dnl AC_DEFUN([AM_DISABLE_FAST_INSTALL], [])
 # _LT_WITH_PIC([MODE])
 # --------------------
 # implement the --with-pic flag, and support the `pic-only' and `no-pic'
-# LT_INIT options.
+# LT_INIT option.
 # MODE is either `yes' or `no'.  If omitted, it defaults to `both'.
 m4_define([_LT_WITH_PIC],
 [AC_ARG_WITH([pic],
@@ -8876,7 +8876,7 @@ AC_CACHE_CHECK([dependency style of $depcc],
        grep sub/conftst6.h sub/conftest.Po > /dev/null 2>&1 &&
        grep $am__obj sub/conftest.Po > /dev/null 2>&1 &&
        ${MAKE-make} -s -f confmf > /dev/null 2>&1; then
-      # icc doesn't choke on unknown options, it will just issue warnings
+      # icc doesn't choke on unknown option, it will just issue warnings
       # or remarks (even with -Werror).  So we grep stderr for any message
       # that says an option was ignored or not supported.
       # When given -MP, icc 7.0 and 7.1 complain thusly:
@@ -9379,7 +9379,7 @@ AC_DEFUN([_AM_SET_OPTION],
 
 # _AM_SET_OPTIONS(OPTIONS)
 # ------------------------
-# OPTIONS is a space-separated list of Automake options.
+# OPTIONS is a space-separated list of Automake option.
 AC_DEFUN([_AM_SET_OPTIONS],
 [m4_foreach_w([_AM_Option], [$1], [_AM_SET_OPTION(_AM_Option)])])
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/ipc/shmem/config.guess
----------------------------------------------------------------------
diff --git a/ipc/shmem/config.guess b/ipc/shmem/config.guess
index 499bfa7..f5856d2 100755
--- a/ipc/shmem/config.guess
+++ b/ipc/shmem/config.guess
@@ -1055,8 +1055,8 @@ EOF
 	echo ${UNAME_MACHINE}-unknown-sysv${UNAME_RELEASE}${UNAME_SYSTEM}${UNAME_VERSION}
 	exit ;;
     i*86:*:3.2:*)
-	if test -f /usr/options/cb.name; then
-		UNAME_REL=`sed -n 's/.*Version //p' </usr/options/cb.name`
+	if test -f /usr/option/cb.name; then
+		UNAME_REL=`sed -n 's/.*Version //p' </usr/option/cb.name`
 		echo ${UNAME_MACHINE}-pc-isc$UNAME_REL
 	elif /bin/uname -X 2>/dev/null >/dev/null ; then
 		UNAME_REL=`(/bin/uname -X|grep Release|sed -e 's/.*= //')`

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/ipc/shmem/configure
----------------------------------------------------------------------
diff --git a/ipc/shmem/configure b/ipc/shmem/configure
index 0fa6dc9..292b71b 100755
--- a/ipc/shmem/configure
+++ b/ipc/shmem/configure
@@ -778,12 +778,12 @@ CPP
 CXXCPP'
 
 
-# Initialize some variables set by options.
+# Initialize some variables set by option.
 ac_init_help=
 ac_init_version=false
 ac_unrecognized_opts=
 ac_unrecognized_sep=
-# The variables have the same names as the options, with
+# The variables have the same names as the option, with
 # dashes changed to underlines.
 cache_file=/dev/null
 exec_prefix=NONE
@@ -800,7 +800,7 @@ verbose=
 x_includes=NONE
 x_libraries=NONE
 
-# Installation directory options.
+# Installation directory option.
 # These are left unexpanded so users can "make install exec_prefix=/foo"
 # and all the variables that are supposed to be based on exec_prefix
 # by default will actually change.
@@ -843,7 +843,7 @@ do
   *)    ac_optarg=yes ;;
   esac
 
-  # Accept the important Cygnus configure options, so we can diagnose typos.
+  # Accept the important Cygnus configure option, so we can diagnose typos.
 
   case $ac_dashdash$ac_option in
   --)
@@ -1194,8 +1194,8 @@ fi
 if test -n "$ac_unrecognized_opts"; then
   case $enable_option_checking in
     no) ;;
-    fatal) as_fn_error $? "unrecognized options: $ac_unrecognized_opts" ;;
-    *)     $as_echo "$as_me: WARNING: unrecognized options: $ac_unrecognized_opts" >&2 ;;
+    fatal) as_fn_error $? "unrecognized option: $ac_unrecognized_opts" ;;
+    *)     $as_echo "$as_me: WARNING: unrecognized option: $ac_unrecognized_opts" >&2 ;;
   esac
 fi
 
@@ -1313,7 +1313,7 @@ done
 # Report the --help message.
 #
 if test "$ac_init_help" = "long"; then
-  # Omit some internal or obsolete options to make the list less imposing.
+  # Omit some internal or obsolete option to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
 \`configure' configures ignite-shmem 1.0 to adapt to many kinds of systems.
@@ -1323,11 +1323,11 @@ Usage: $0 [OPTION]... [VAR=VALUE]...
 To assign environment variables (e.g., CC, CFLAGS...), specify them as
 VAR=VALUE.  See below for descriptions of some of the useful variables.
 
-Defaults for the options are specified in brackets.
+Defaults for the option are specified in brackets.
 
 Configuration:
   -h, --help              display this help and exit
-      --help=short        display options specific to this package
+      --help=short        display option specific to this package
       --help=recursive    display the short help of all the included packages
   -V, --version           display version information and exit
   -q, --quiet, --silent   do not print \`checking ...' messages
@@ -1347,7 +1347,7 @@ By default, \`make install' will install all the files in
 an installation prefix other than \`$ac_default_prefix' using \`--prefix',
 for instance \`--prefix=\$HOME'.
 
-For better control, use the options below.
+For better control, use the option below.
 
 Fine tuning of the installation directories:
   --bindir=DIR            user executables [EPREFIX/bin]
@@ -1392,7 +1392,7 @@ if test -n "$ac_init_help"; then
   cat <<\_ACEOF
 
 Optional Features:
-  --disable-option-checking  ignore unrecognized --enable/--with options
+  --disable-option-checking  ignore unrecognized --enable/--with option
   --disable-FEATURE       do not include FEATURE (same as --enable-FEATURE=no)
   --enable-FEATURE[=ARG]  include FEATURE [ARG=yes]
   --disable-dependency-tracking  speeds up one-time build
@@ -3877,7 +3877,7 @@ else
        grep sub/conftst6.h sub/conftest.Po > /dev/null 2>&1 &&
        grep $am__obj sub/conftest.Po > /dev/null 2>&1 &&
        ${MAKE-make} -s -f confmf > /dev/null 2>&1; then
-      # icc doesn't choke on unknown options, it will just issue warnings
+      # icc doesn't choke on unknown option, it will just issue warnings
       # or remarks (even with -Werror).  So we grep stderr for any message
       # that says an option was ignored or not supported.
       # When given -MP, icc 7.0 and 7.1 complain thusly:
@@ -4391,7 +4391,7 @@ else
        grep sub/conftst6.h sub/conftest.Po > /dev/null 2>&1 &&
        grep $am__obj sub/conftest.Po > /dev/null 2>&1 &&
        ${MAKE-make} -s -f confmf > /dev/null 2>&1; then
-      # icc doesn't choke on unknown options, it will just issue warnings
+      # icc doesn't choke on unknown option, it will just issue warnings
       # or remarks (even with -Werror).  So we grep stderr for any message
       # that says an option was ignored or not supported.
       # When given -MP, icc 7.0 and 7.1 complain thusly:
@@ -7964,7 +7964,7 @@ func_stripname_cnf ()
 
 
 
-# Set options
+# Set option
 
 
 
@@ -8560,7 +8560,7 @@ lt_prog_compiler_static=
       ;;
 
     interix[3-9]*)
-      # Interix 3.x gcc -fpic/-fPIC options generate broken code.
+      # Interix 3.x gcc -fpic/-fPIC option generate broken code.
       # Instead, we relocate shared libraries at runtime.
       ;;
 
@@ -10086,7 +10086,7 @@ $as_echo "$lt_cv_irix_exported_symbol" >&6; }
       case $host_os in
       solaris2.[0-5] | solaris2.[0-5].*) ;;
       *)
-	# The compiler driver will combine and reorder linker options,
+	# The compiler driver will combine and reorder linker option,
 	# but understands `-z linker_flag'.  GCC discards it without `$wl',
 	# but is careful enough not to reorder.
 	# Supported since Solaris 2.6 (maybe 2.5.1?)
@@ -13233,7 +13233,7 @@ fi
 	    case $host_os in
 	      solaris2.[0-5] | solaris2.[0-5].*) ;;
 	      *)
-		# The compiler driver will combine and reorder linker options,
+		# The compiler driver will combine and reorder linker option,
 		# but understands `-z linker_flag'.
 	        # Supported since Solaris 2.6 (maybe 2.5.1?)
 		whole_archive_flag_spec_CXX='-z allextract$convenience -z defaultextract'
@@ -13658,7 +13658,7 @@ lt_prog_compiler_static_CXX=
       lt_prog_compiler_static_CXX=
       ;;
     interix[3-9]*)
-      # Interix 3.x gcc -fpic/-fPIC options generate broken code.
+      # Interix 3.x gcc -fpic/-fPIC option generate broken code.
       # Instead, we relocate shared libraries at runtime.
       ;;
     sysv4*MP*)
@@ -15687,7 +15687,7 @@ test $as_write_fail = 0 && chmod +x $CONFIG_STATUS || ac_write_fail=1
 cat >>$CONFIG_STATUS <<\_ACEOF || ac_write_fail=1
 # Save the log message, to keep $0 and so on meaningful, and to
 # report actual input values of CONFIG_FILES etc. instead of their
-# values after options handling.
+# values after option handling.
 ac_log="
 This file was extended by ignite-shmem $as_me 1.0, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
@@ -15757,7 +15757,7 @@ ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g
 ac_cs_version="\\
 ignite-shmem config.status 1.0
 configured by $0, generated by GNU Autoconf 2.69,
-  with options \\"\$ac_cs_config\\"
+  with option \\"\$ac_cs_config\\"
 
 Copyright (C) 2012 Free Software Foundation, Inc.
 This config.status script is free software; the Free Software Foundation
@@ -15795,7 +15795,7 @@ do
   esac
 
   case $ac_option in
-  # Handling of the options.
+  # Handling of the option.
   -recheck | --recheck | --rechec | --reche | --rech | --rec | --re | --r)
     ac_cs_recheck=: ;;
   --version | --versio | --versi | --vers | --ver | --ve | --v | -V )
@@ -16233,7 +16233,7 @@ ac_aux_dir='$ac_aux_dir'
 xsi_shell='$xsi_shell'
 lt_shell_append='$lt_shell_append'
 
-# See if we are running on zsh, and set the options which allow our
+# See if we are running on zsh, and set the option which allow our
 # commands through without removal of \ escapes INIT.
 if test -n "\${ZSH_VERSION+set}" ; then
    setopt NO_GLOB_SUBST
@@ -16957,7 +16957,7 @@ $as_echo X"$file" |
  ;;
     "libtool":C)
 
-    # See if we are running on zsh, and set the options which allow our
+    # See if we are running on zsh, and set the option which allow our
     # commands through without removal of \ escapes.
     if test -n "${ZSH_VERSION+set}" ; then
       setopt NO_GLOB_SUBST
@@ -17047,7 +17047,7 @@ build_os=$build_os
 # A sed program that does not truncate output.
 SED=$lt_SED
 
-# Sed that helps us avoid accidentally triggering echo(1) options like -n.
+# Sed that helps us avoid accidentally triggering echo(1) option like -n.
 Xsed="\$SED -e 1s/^X//"
 
 # A grep program that handles long lines.
@@ -17289,7 +17289,7 @@ wl=$lt_lt_prog_compiler_wl
 # Compiler flag to prevent dynamic linking.
 link_static_flag=$lt_lt_prog_compiler_static
 
-# Does compiler simultaneously support -c and -o options?
+# Does compiler simultaneously support -c and -o option?
 compiler_c_o=$lt_lt_cv_prog_compiler_c_o
 
 # Whether or not to add -lc for building shared libraries.
@@ -17631,7 +17631,7 @@ wl=$lt_lt_prog_compiler_wl_CXX
 # Compiler flag to prevent dynamic linking.
 link_static_flag=$lt_lt_prog_compiler_static_CXX
 
-# Does compiler simultaneously support -c and -o options?
+# Does compiler simultaneously support -c and -o option?
 compiler_c_o=$lt_lt_cv_prog_compiler_c_o_CXX
 
 # Whether or not to add -lc for building shared libraries.
@@ -17786,6 +17786,6 @@ if test "$no_create" != yes; then
   $ac_cs_success || as_fn_exit 1
 fi
 if test -n "$ac_unrecognized_opts" && test "$enable_option_checking" != no; then
-  { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: unrecognized options: $ac_unrecognized_opts" >&5
-$as_echo "$as_me: WARNING: unrecognized options: $ac_unrecognized_opts" >&2;}
+  { $as_echo "$as_me:${as_lineno-$LINENO}: WARNING: unrecognized option: $ac_unrecognized_opts" >&5
+$as_echo "$as_me: WARNING: unrecognized option: $ac_unrecognized_opts" >&2;}
 fi

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/ipc/shmem/igniteshmem/Makefile.am
----------------------------------------------------------------------
diff --git a/ipc/shmem/igniteshmem/Makefile.am b/ipc/shmem/igniteshmem/Makefile.am
index a7c1d71..2ac3f29 100644
--- a/ipc/shmem/igniteshmem/Makefile.am
+++ b/ipc/shmem/igniteshmem/Makefile.am
@@ -28,10 +28,10 @@ lib_LTLIBRARIES = libigniteshmem.la
 # Sources for igniteshmem
 libigniteshmem_la_SOURCES = org_apache_ignite_internal_util_ipc_shmem_IpcSharedMemoryUtils.cpp
 
-# Linker options libTestProgram
+# Linker option libTestProgram
 libigniteshmem_la_LDFLAGS =
 
-# Compiler options. Here we are adding the include directory
+# Compiler option. Here we are adding the include directory
 # to be searched for headers included in the source code.
 libigniteshmem_la_CPPFLAGS = -I$(top_srcdir)/include -I$(JAVA_HOME)/include -I$(JAVA_HOME)/include/linux -I$(JAVA_HOME)/include/darwin \
 -I/System/Library/Frameworks/JavaVM.framework/Headers

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/ipc/shmem/igniteshmem/Makefile.in
----------------------------------------------------------------------
diff --git a/ipc/shmem/igniteshmem/Makefile.in b/ipc/shmem/igniteshmem/Makefile.in
index 34782dc..251fb64 100644
--- a/ipc/shmem/igniteshmem/Makefile.in
+++ b/ipc/shmem/igniteshmem/Makefile.in
@@ -258,10 +258,10 @@ lib_LTLIBRARIES = libigniteshmem.la
 # Sources for igniteshmem
 libigniteshmem_la_SOURCES = org_apache_ignite_internal_util_ipc_shmem_IpcSharedMemoryUtils.cpp
 
-# Linker options libTestProgram
+# Linker option libTestProgram
 libigniteshmem_la_LDFLAGS =
 
-# Compiler options. Here we are adding the include directory
+# Compiler option. Here we are adding the include directory
 # to be searched for headers included in the source code.
 libigniteshmem_la_CPPFLAGS = -I$(top_srcdir)/include -I$(JAVA_HOME)/include -I$(JAVA_HOME)/include/linux -I$(JAVA_HOME)/include/darwin \
 -I/System/Library/Frameworks/JavaVM.framework/Headers

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/ipc/shmem/install-sh
----------------------------------------------------------------------
diff --git a/ipc/shmem/install-sh b/ipc/shmem/install-sh
index a9244eb..c055f57 100755
--- a/ipc/shmem/install-sh
+++ b/ipc/shmem/install-sh
@@ -459,7 +459,7 @@ do
     # Copy the file name to the temp name.
     (umask $cp_umask && $doit_exec $cpprog "$src" "$dsttmp") &&
 
-    # and set any options; do chmod last to preserve setuid bits.
+    # and set any option; do chmod last to preserve setuid bits.
     #
     # If any of these fail, we abort the whole thing.  If we want to
     # ignore errors from any of these, just make sure not to ignore

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/ipc/shmem/ltmain.sh
----------------------------------------------------------------------
diff --git a/ipc/shmem/ltmain.sh b/ipc/shmem/ltmain.sh
index af3f40d..74a5202 100644
--- a/ipc/shmem/ltmain.sh
+++ b/ipc/shmem/ltmain.sh
@@ -430,7 +430,7 @@ sed_double_backslash="\
   s/\\([^$bs]\\)$bs2$dollar/\\1$bs2$bs$dollar/g
   s/\n//g"
 
-# Standard options:
+# Standard option:
 opt_dry_run=false
 opt_help=false
 opt_quiet=false
@@ -1057,7 +1057,7 @@ opt_silent=false
 opt_verbose=false
 
 
-# Parse options once, thoroughly.  This comes as soon as possible in the
+# Parse option once, thoroughly.  This comes as soon as possible in the
 # script to make things like `--version' happen as quickly as we can.
 {
   # this just eases exit handling
@@ -1151,14 +1151,14 @@ func_enable_tag "$optarg"
       --help)		func_help				;;
       --version)	func_version				;;
 
-      # Separate optargs to long options:
+      # Separate optargs to long option:
       --*=*)
 			func_split_long_opt "$opt"
 			set dummy "$func_split_long_opt_name" "$func_split_long_opt_arg" ${1+"$@"}
 			shift
 			;;
 
-      # Separate non-argument short options:
+      # Separate non-argument short option:
       -\?*|-h*|-n*|-v*)
 			func_split_short_opt "$opt"
 			set dummy "$func_split_short_opt_name" "-$func_split_short_opt_arg" ${1+"$@"}
@@ -1171,7 +1171,7 @@ func_enable_tag "$optarg"
     esac
   done
 
-  # Validate options:
+  # Validate option:
 
   # save first non-option argument
   if test "$#" -gt 0; then
@@ -1216,7 +1216,7 @@ func_enable_tag "$optarg"
   }
 
 
-  # Bail if the options were screwed
+  # Bail if the option were screwed
   $exit_cmd $EXIT_FAILURE
 }
 
@@ -1979,7 +1979,7 @@ func_mode_compile ()
 	;;
 
       normal )
-	# Accept any command-line options.
+	# Accept any command-line option.
 	case $arg in
 	-o)
 	  test -n "$libobj" && \
@@ -2314,7 +2314,7 @@ func_mode_help ()
 Remove files from the build directory.
 
 RM is the name of the program to use to delete files associated with each FILE
-(typically \`/bin/rm').  RM-OPTIONS are options (such as \`-f') to be passed
+(typically \`/bin/rm').  RM-OPTIONS are option (such as \`-f') to be passed
 to RM.
 
 If FILE is a libtool library, object or program, all the files associated
@@ -2327,7 +2327,7 @@ with it are deleted. Otherwise, only FILE itself is deleted using RM."
 
 Compile a source file into a libtool library object.
 
-This mode accepts the following additional options:
+This mode accepts the following additional option:
 
   -o OUTPUT-FILE    set the output file name to OUTPUT-FILE
   -no-suppress      do not suppress compiler output for multiple passes
@@ -2351,7 +2351,7 @@ library object suffix, \`.lo'."
 
 Automatically set library path, then run a program.
 
-This mode accepts the following additional options:
+This mode accepts the following additional option:
 
   -dlopen FILE      add the directory containing FILE to the library path
 
@@ -2391,7 +2391,7 @@ The following components of INSTALL-COMMAND are treated specially:
   -inst-prefix-dir PREFIX-DIR  Use PREFIX-DIR as a staging area for installation
 
 The rest of the components are interpreted as arguments to that command (only
-BSD-compatible install options are recognized)."
+BSD-compatible install option are recognized)."
         ;;
 
       link)
@@ -2444,7 +2444,7 @@ The following components of LINK-COMMAND are treated specially:
   -Xlinker FLAG     pass linker-specific FLAG directly to the linker
   -XCClinker FLAG   pass link-specific FLAG to the compiler driver (CC)
 
-All other options (arguments beginning with \`-') are ignored.
+All other option (arguments beginning with \`-') are ignored.
 
 Every other argument is treated as a filename.  Files ending in \`.la' are
 treated as uninstalled libtool libraries, other files are standard or library
@@ -2468,7 +2468,7 @@ is created, otherwise an executable program is created."
 Remove libraries from an installation directory.
 
 RM is the name of the program to use to delete files associated with each FILE
-(typically \`/bin/rm').  RM-OPTIONS are options (such as \`-f') to be passed
+(typically \`/bin/rm').  RM-OPTIONS are option (such as \`-f') to be passed
 to RM.
 
 If FILE is a libtool library, all the files associated with it are deleted.
@@ -3899,14 +3899,14 @@ _LTECHO_EOF'
     ECHO=\"$qECHO\"
   fi
 
-# Very basic option parsing. These options are (a) specific to
+# Very basic option parsing. These option are (a) specific to
 # the libtool wrapper, (b) are identical between the wrapper
 # /script/ and the wrapper /executable/ which is used only on
 # windows platforms, and (c) all begin with the string "--lt-"
-# (application programs are unlikely to have options which match
+# (application programs are unlikely to have option which match
 # this pattern).
 #
-# There are only two supported options: --lt-debug and
+# There are only two supported option: --lt-debug and
 # --lt-dump-script. There is, deliberately, no --lt-help.
 #
 # The first argument to this parsing function should be the
@@ -3984,7 +3984,7 @@ func_exec_program_core ()
 }
 
 # A function to encapsulate launching the target application
-# Strips options in the --lt-* namespace from \$@ and
+# Strips option in the --lt-* namespace from \$@ and
 # launches target application with the remaining arguments.
 func_exec_program ()
 {
@@ -4002,7 +4002,7 @@ func_exec_program ()
   func_exec_program_core \${1+\"\$@\"}
 }
 
-  # Parse options
+  # Parse option
   func_parse_lt_options \"\$0\" \${1+\"\$@\"}
 
   # Find the directory that this script lives in.
@@ -4368,7 +4368,7 @@ main (int argc, char *argv[])
   newargz = XMALLOC (char *, argc + 1);
 
   /* very simple arg parsing; don't want to rely on getopt
-   * also, copy all non cwrapper options to newargz, except
+   * also, copy all non cwrapper option to newargz, except
    * argz[0], which is handled differently
    */
   newargc=0;
@@ -4399,7 +4399,7 @@ EOF
              namespace, but it is not one of the ones we know about and
              have already dealt with, above (inluding dump-script), then
              report an error. Otherwise, targets might begin to believe
-             they are allowed to use options in the LTWRAPPER_OPTION_PREFIX
+             they are allowed to use option in the LTWRAPPER_OPTION_PREFIX
              namespace. The first time any user complains about this, we'll
              need to make LTWRAPPER_OPTION_PREFIX a configure-time option
              or a configure.ac-settable value.
@@ -7410,7 +7410,7 @@ func_mode_link ()
 	  func_arith $current - $age
 	  major=.$func_arith_result
 	  versuffix="$major.$age.$revision"
-	  # Darwin ld doesn't like 0 for these options...
+	  # Darwin ld doesn't like 0 for these option...
 	  func_arith $current + 1
 	  minor_current=$func_arith_result
 	  xlcverstring="${wl}-compatibility_version ${wl}$minor_current ${wl}-current_version ${wl}$minor_current.$revision"

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/ipc/shmem/m4/libtool.m4
----------------------------------------------------------------------
diff --git a/ipc/shmem/m4/libtool.m4 b/ipc/shmem/m4/libtool.m4
index 828104c..5832d35 100644
--- a/ipc/shmem/m4/libtool.m4
+++ b/ipc/shmem/m4/libtool.m4
@@ -179,7 +179,7 @@ m4_require([_LT_CMD_GLOBAL_SYMBOLS])dnl
 m4_require([_LT_WITH_SYSROOT])dnl
 
 _LT_CONFIG_LIBTOOL_INIT([
-# See if we are running on zsh, and set the options which allow our
+# See if we are running on zsh, and set the option which allow our
 # commands through without removal of \ escapes INIT.
 if test -n "\${ZSH_VERSION+set}" ; then
    setopt NO_GLOB_SUBST
@@ -705,7 +705,7 @@ m4_defun([_LT_CONFIG],
 _LT_CONFIG_SAVE_COMMANDS([
   m4_define([_LT_TAG], m4_if([$1], [], [C], [$1]))dnl
   m4_if(_LT_TAG, [C], [
-    # See if we are running on zsh, and set the options which allow our
+    # See if we are running on zsh, and set the option which allow our
     # commands through without removal of \ escapes.
     if test -n "${ZSH_VERSION+set}" ; then
       setopt NO_GLOB_SUBST
@@ -1965,7 +1965,7 @@ dnl AC_DEFUN([AC_LIBTOOL_DLOPEN_SELF], [])
 
 # _LT_COMPILER_C_O([TAGNAME])
 # ---------------------------
-# Check to see if options -c and -o are simultaneously supported by compiler.
+# Check to see if option -c and -o are simultaneously supported by compiler.
 # This macro does not hard code the compiler like AC_PROG_CC_C_O.
 m4_defun([_LT_COMPILER_C_O],
 [m4_require([_LT_DECL_SED])dnl
@@ -2015,7 +2015,7 @@ AC_CACHE_CHECK([if $compiler supports -c -o file.$ac_objext],
    $RM conftest*
 ])
 _LT_TAGDECL([compiler_c_o], [lt_cv_prog_compiler_c_o], [1],
-	[Does compiler simultaneously support -c and -o options?])
+	[Does compiler simultaneously support -c and -o option?])
 ])# _LT_COMPILER_C_O
 
 
@@ -3939,7 +3939,7 @@ m4_if([$1], [CXX], [
       _LT_TAGVAR(lt_prog_compiler_static, $1)=
       ;;
     interix[[3-9]]*)
-      # Interix 3.x gcc -fpic/-fPIC options generate broken code.
+      # Interix 3.x gcc -fpic/-fPIC option generate broken code.
       # Instead, we relocate shared libraries at runtime.
       ;;
     sysv4*MP*)
@@ -4270,7 +4270,7 @@ m4_if([$1], [CXX], [
       ;;
 
     interix[[3-9]]*)
-      # Interix 3.x gcc -fpic/-fPIC options generate broken code.
+      # Interix 3.x gcc -fpic/-fPIC option generate broken code.
       # Instead, we relocate shared libraries at runtime.
       ;;
 
@@ -5477,7 +5477,7 @@ _LT_EOF
       case $host_os in
       solaris2.[[0-5]] | solaris2.[[0-5]].*) ;;
       *)
-	# The compiler driver will combine and reorder linker options,
+	# The compiler driver will combine and reorder linker option,
 	# but understands `-z linker_flag'.  GCC discards it without `$wl',
 	# but is careful enough not to reorder.
 	# Supported since Solaris 2.6 (maybe 2.5.1?)
@@ -6731,7 +6731,7 @@ if test "$_lt_caught_CXX_error" != yes; then
 	    case $host_os in
 	      solaris2.[[0-5]] | solaris2.[[0-5]].*) ;;
 	      *)
-		# The compiler driver will combine and reorder linker options,
+		# The compiler driver will combine and reorder linker option,
 		# but understands `-z linker_flag'.
 	        # Supported since Solaris 2.6 (maybe 2.5.1?)
 		_LT_TAGVAR(whole_archive_flag_spec, $1)='-z allextract$convenience -z defaultextract'
@@ -7718,7 +7718,7 @@ test -z "$SED" && SED=sed
 Xsed="$SED -e 1s/^X//"
 _LT_DECL([], [SED], [1], [A sed program that does not truncate output])
 _LT_DECL([], [Xsed], ["\$SED -e 1s/^X//"],
-    [Sed that helps us avoid accidentally triggering echo(1) options like -n])
+    [Sed that helps us avoid accidentally triggering echo(1) option like -n])
 ])# _LT_DECL_SED
 
 m4_ifndef([AC_PROG_SED], [

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/ipc/shmem/m4/ltoptions.m4
----------------------------------------------------------------------
diff --git a/ipc/shmem/m4/ltoptions.m4 b/ipc/shmem/m4/ltoptions.m4
index 5d9acd8..6bc9a30 100644
--- a/ipc/shmem/m4/ltoptions.m4
+++ b/ipc/shmem/m4/ltoptions.m4
@@ -42,7 +42,7 @@ m4_define([_LT_IF_OPTION],
 
 # _LT_UNLESS_OPTIONS(MACRO-NAME, OPTION-LIST, IF-NOT-SET)
 # -------------------------------------------------------
-# Execute IF-NOT-SET unless all options in OPTION-LIST for MACRO-NAME
+# Execute IF-NOT-SET unless all option in OPTION-LIST for MACRO-NAME
 # are set.
 m4_define([_LT_UNLESS_OPTIONS],
 [m4_foreach([_LT_Option], m4_split(m4_normalize([$2])),
@@ -55,25 +55,25 @@ m4_ifdef([$0_found], [m4_undefine([$0_found])], [$3
 
 # _LT_SET_OPTIONS(MACRO-NAME, OPTION-LIST)
 # ----------------------------------------
-# OPTION-LIST is a space-separated list of Libtool options associated
+# OPTION-LIST is a space-separated list of Libtool option associated
 # with MACRO-NAME.  If any OPTION has a matching handler declared with
 # LT_OPTION_DEFINE, dispatch to that macro; otherwise complain about
 # the unknown option and exit.
 m4_defun([_LT_SET_OPTIONS],
-[# Set options
+[# Set option
 m4_foreach([_LT_Option], m4_split(m4_normalize([$2])),
     [_LT_SET_OPTION([$1], _LT_Option)])
 
 m4_if([$1],[LT_INIT],[
   dnl
-  dnl Simply set some default values (i.e off) if boolean options were not
+  dnl Simply set some default values (i.e off) if boolean option were not
   dnl specified:
   _LT_UNLESS_OPTIONS([LT_INIT], [dlopen], [enable_dlopen=no
   ])
   _LT_UNLESS_OPTIONS([LT_INIT], [win32-dll], [enable_win32_dll=no
   ])
   dnl
-  dnl If no reference was made to various pairs of opposing options, then
+  dnl If no reference was made to various pairs of opposing option, then
   dnl we run the default mode handler for the pair.  For example, if neither
   dnl `shared' nor `disable-shared' was passed, we enable building of shared
   dnl archives by default:
@@ -87,7 +87,7 @@ m4_if([$1],[LT_INIT],[
 
 
 ## --------------------------------- ##
-## Macros to handle LT_INIT options. ##
+## Macros to handle LT_INIT option. ##
 ## --------------------------------- ##
 
 # _LT_MANGLE_DEFUN(MACRO-NAME, OPTION-NAME)
@@ -158,7 +158,7 @@ dnl AC_DEFUN([AC_LIBTOOL_WIN32_DLL], [])
 # _LT_ENABLE_SHARED([DEFAULT])
 # ----------------------------
 # implement the --enable-shared flag, and supports the `shared' and
-# `disable-shared' LT_INIT options.
+# `disable-shared' LT_INIT option.
 # DEFAULT is either `yes' or `no'.  If omitted, it defaults to `yes'.
 m4_define([_LT_ENABLE_SHARED],
 [m4_define([_LT_ENABLE_SHARED_DEFAULT], [m4_if($1, no, no, yes)])dnl
@@ -212,7 +212,7 @@ dnl AC_DEFUN([AM_DISABLE_SHARED], [])
 # _LT_ENABLE_STATIC([DEFAULT])
 # ----------------------------
 # implement the --enable-static flag, and support the `static' and
-# `disable-static' LT_INIT options.
+# `disable-static' LT_INIT option.
 # DEFAULT is either `yes' or `no'.  If omitted, it defaults to `yes'.
 m4_define([_LT_ENABLE_STATIC],
 [m4_define([_LT_ENABLE_STATIC_DEFAULT], [m4_if($1, no, no, yes)])dnl
@@ -266,7 +266,7 @@ dnl AC_DEFUN([AM_DISABLE_STATIC], [])
 # _LT_ENABLE_FAST_INSTALL([DEFAULT])
 # ----------------------------------
 # implement the --enable-fast-install flag, and support the `fast-install'
-# and `disable-fast-install' LT_INIT options.
+# and `disable-fast-install' LT_INIT option.
 # DEFAULT is either `yes' or `no'.  If omitted, it defaults to `yes'.
 m4_define([_LT_ENABLE_FAST_INSTALL],
 [m4_define([_LT_ENABLE_FAST_INSTALL_DEFAULT], [m4_if($1, no, no, yes)])dnl
@@ -322,7 +322,7 @@ dnl AC_DEFUN([AM_DISABLE_FAST_INSTALL], [])
 # _LT_WITH_PIC([MODE])
 # --------------------
 # implement the --with-pic flag, and support the `pic-only' and `no-pic'
-# LT_INIT options.
+# LT_INIT option.
 # MODE is either `yes' or `no'.  If omitted, it defaults to `both'.
 m4_define([_LT_WITH_PIC],
 [AC_ARG_WITH([pic],

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/aop/src/test/config/aop/aspectj/META-INF/aop.xml
----------------------------------------------------------------------
diff --git a/modules/aop/src/test/config/aop/aspectj/META-INF/aop.xml b/modules/aop/src/test/config/aop/aspectj/META-INF/aop.xml
index 79417da..9c763e4 100644
--- a/modules/aop/src/test/config/aop/aspectj/META-INF/aop.xml
+++ b/modules/aop/src/test/config/aop/aspectj/META-INF/aop.xml
@@ -22,7 +22,7 @@
     "http://www.eclipse.org/aspectj/dtd/aspectj_1_5_0.dtd">
 
 <aspectj>
-    <weaver options="-Xset:weaveJavaPackages=true,weaveJavaxPackages=true -Xreweavable">
+    <weaver option="-Xset:weaveJavaPackages=true,weaveJavaxPackages=true -Xreweavable">
         <!-- BEA libs. -->
         <exclude within="weblogic..*"/>
         <exclude within="com.bea..*"/>

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/cassandra/store/src/test/bootstrap/aws/cassandra/cassandra-env.sh
----------------------------------------------------------------------
diff --git a/modules/cassandra/store/src/test/bootstrap/aws/cassandra/cassandra-template.yaml b/modules/cassandra/store/src/test/bootstrap/aws/cassandra/cassandra-template.yaml
index e621886..34f3897 100644
--- a/modules/cassandra/store/src/test/bootstrap/aws/cassandra/cassandra-template.yaml
+++ b/modules/cassandra/store/src/test/bootstrap/aws/cassandra/cassandra-template.yaml
@@ -520,7 +520,7 @@ broadcast_rpc_address:
 # enable or disable keepalive on rpc/native connections
 rpc_keepalive: true
 
-# Cassandra provides two out-of-the-box options for the RPC Server:
+# Cassandra provides two out-of-the-box option for the RPC Server:
 #
 # sync  -> One thread per thrift connection. For a very large number of clients, memory
 #          will be your limiting factor. On a 64 bit JVM, 180KB is the minimum stack size
@@ -787,7 +787,7 @@ dynamic_snitch_badness_threshold: 0.1
 request_scheduler: org.apache.cassandra.scheduler.NoScheduler
 
 # Scheduler Options vary based on the type of scheduler
-# NoScheduler - Has no options
+# NoScheduler - Has no option
 # RoundRobin
 #  - throttle_limit -- The throttle_limit is the number of in-flight
 #                      requests per client.  Requests beyond 
@@ -818,13 +818,13 @@ request_scheduler: org.apache.cassandra.scheduler.NoScheduler
 # users generate their own keys) TLS_RSA_WITH_AES_128_CBC_SHA as the cipher
 # suite for authentication, key exchange and encryption of the actual data transfers.
 # Use the DHE/ECDHE ciphers if running in FIPS 140 compliant mode.
-# NOTE: No custom encryption options are enabled at the moment
-# The available internode options are : all, none, dc, rack
+# NOTE: No custom encryption option are enabled at the moment
+# The available internode option are : all, none, dc, rack
 #
 # If set to dc cassandra will encrypt the traffic between the DCs
 # If set to rack cassandra will encrypt the traffic between the racks
 #
-# The passwords used in these options must match the passwords used when generating
+# The passwords used in these option must match the passwords used when generating
 # the keystore and truststore.  For instructions on generating these files, see:
 # http://download.oracle.com/javase/6/docs/technotes/guides/security/jsse/JSSERefGuide.html#CreateKeystore
 #

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/blob/ignite-config.xml
----------------------------------------------------------------------
diff --git a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/blob/ignite-config.xml b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/blob/ignite-config.xml
index fbf38e9..d1b1fb7 100644
--- a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/blob/ignite-config.xml
+++ b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/blob/ignite-config.xml
@@ -73,8 +73,8 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
-                        instead os static IP based discovery. For information on all options refer
+                        Ignite provides several option for automatic discovery that can be used
+                        instead os static IP based discovery. For information on all option refer
                         to our documentation: http://apacheignite.readme.io/docs/cluster-config
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/ignite-config.xml
----------------------------------------------------------------------
diff --git a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/ignite-config.xml b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/ignite-config.xml
index c9b45c8..5978cab 100644
--- a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/ignite-config.xml
+++ b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/ignite-config.xml
@@ -148,8 +148,8 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
-                        instead os static IP based discovery. For information on all options refer
+                        Ignite provides several option for automatic discovery that can be used
+                        instead os static IP based discovery. For information on all option refer
                         to our documentation: http://apacheignite.readme.io/docs/cluster-config
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/persistence-settings-3.xml
----------------------------------------------------------------------
diff --git a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/persistence-settings-3.xml b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/persistence-settings-3.xml
index f602508..6afae66 100644
--- a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/persistence-settings-3.xml
+++ b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/persistence-settings-3.xml
@@ -27,7 +27,7 @@ Attributes:
 -->
 <persistence keyspace="test1" table="pojo_test3" ttl="86400">
     <!--
-    Cassandra keyspace options which should be used to create provided keyspace if it doesn't exist.
+    Cassandra keyspace option which should be used to create provided keyspace if it doesn't exist.
 
     Note: optional element
     -->
@@ -37,7 +37,7 @@ Attributes:
     </keyspaceOptions>
 
     <!--
-    Cassandra table options which should be used to create provided table if it doesn't exist.
+    Cassandra table option which should be used to create provided table if it doesn't exist.
 
     Note: optional element
     -->
@@ -159,7 +159,7 @@ Attributes:
            3) static       [optional] - boolean flag which specifies that column is static withing a given partition
            4) index        [optional] - boolean flag specifying that secondary index should be created for the field
            5) indexClass   [optional] - custom index java class name, in case you want to use custom index
-           6) indexOptions [optional] - custom index options
+           6) indexOptions [optional] - custom index option
         -->
         <field name="personNumber" column="number" />
         <field name="firstName" column="first_name" />

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/persistence-settings-4.xml
----------------------------------------------------------------------
diff --git a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/persistence-settings-4.xml b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/persistence-settings-4.xml
index 490d8e7..97d7d7c 100644
--- a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/persistence-settings-4.xml
+++ b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/pojo/persistence-settings-4.xml
@@ -27,7 +27,7 @@ Attributes:
 -->
 <persistence keyspace="test1" ttl="86400">
     <!--
-    Cassandra keyspace options which should be used to create provided keyspace if it doesn't exist.
+    Cassandra keyspace option which should be used to create provided keyspace if it doesn't exist.
 
     Note: optional element
     -->
@@ -37,7 +37,7 @@ Attributes:
     </keyspaceOptions>
 
     <!--
-    Cassandra table options which should be used to create provided table if it doesn't exist.
+    Cassandra table option which should be used to create provided table if it doesn't exist.
 
     Note: optional element
     -->
@@ -159,7 +159,7 @@ Attributes:
            3) static       [optional] - boolean flag which specifies that column is static withing a given partition
            4) index        [optional] - boolean flag specifying that secondary index should be created for the field
            5) indexClass   [optional] - custom index java class name, in case you want to use custom index
-           6) indexOptions [optional] - custom index options
+           6) indexOptions [optional] - custom index option
         -->
         <field name="personNumber" column="number" />
         <field name="firstName" column="first_name" />

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/primitive/ignite-config.xml
----------------------------------------------------------------------
diff --git a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/primitive/ignite-config.xml b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/primitive/ignite-config.xml
index 13e0922..b679ee2 100644
--- a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/primitive/ignite-config.xml
+++ b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/primitive/ignite-config.xml
@@ -73,8 +73,8 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
-                        instead os static IP based discovery. For information on all options refer
+                        Ignite provides several option for automatic discovery that can be used
+                        instead os static IP based discovery. For information on all option refer
                         to our documentation: http://apacheignite.readme.io/docs/cluster-config
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/primitive/ignite-remote-server-config.xml
----------------------------------------------------------------------
diff --git a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/primitive/ignite-remote-server-config.xml b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/primitive/ignite-remote-server-config.xml
index 8d71aec..de10595 100644
--- a/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/primitive/ignite-remote-server-config.xml
+++ b/modules/cassandra/store/src/test/resources/org/apache/ignite/tests/persistence/primitive/ignite-remote-server-config.xml
@@ -89,8 +89,8 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
-                        instead os static IP based discovery. For information on all options refer
+                        Ignite provides several option for automatic discovery that can be used
+                        instead os static IP based discovery. For information on all option refer
                         to our documentation: http://apacheignite.readme.io/docs/cluster-config
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/platforms/cpp/DEVNOTES.txt
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/DEVNOTES.txt b/modules/platforms/cpp/DEVNOTES.txt
index 473af23..c75a3be 100644
--- a/modules/platforms/cpp/DEVNOTES.txt
+++ b/modules/platforms/cpp/DEVNOTES.txt
@@ -29,8 +29,8 @@ Building the Apache Ignite C++ components:
     * ./configure
     * make
 
-Among standard included by autotools options configure script also include following
-Ignite-specific options:
+Among standard included by autotools option configure script also include following
+Ignite-specific option:
  * --enable-odbc - build included ODBC driver. Disabled by default.
  * --enable-core - build Ignite core library. Enabled by default.
  * --enable-node - build stand-alone node executable. Enabled by default.

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/platforms/cpp/cpp.dxg
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/cpp.dxg b/modules/platforms/cpp/cpp.dxg
index d25d978..d0f4c5e 100644
--- a/modules/platforms/cpp/cpp.dxg
+++ b/modules/platforms/cpp/cpp.dxg
@@ -11,7 +11,7 @@
 # Values that contain spaces should be placed between quotes (" ").
 
 #---------------------------------------------------------------------------
-# Project related configuration options
+# Project related configuration option
 #---------------------------------------------------------------------------
 
 # This tag specifies the encoding used for all characters in the config file
@@ -310,7 +310,7 @@ TYPEDEF_HIDES_STRUCT   = NO
 SYMBOL_CACHE_SIZE      = 0
 
 #---------------------------------------------------------------------------
-# Build related configuration options
+# Build related configuration option
 #---------------------------------------------------------------------------
 
 # If the EXTRACT_ALL tag is set to YES doxygen will assume all entities in
@@ -551,7 +551,7 @@ FILE_VERSION_FILTER    =
 LAYOUT_FILE            =
 
 #---------------------------------------------------------------------------
-# configuration options related to warning and progress messages
+# configuration option related to warning and progress messages
 #---------------------------------------------------------------------------
 
 # The QUIET tag can be used to turn on/off the messages that are generated
@@ -602,7 +602,7 @@ WARN_FORMAT            = "$file:$line: $text"
 WARN_LOGFILE           =
 
 #---------------------------------------------------------------------------
-# configuration options related to the input files
+# configuration option related to the input files
 #---------------------------------------------------------------------------
 
 # The INPUT tag can be used to specify the files and/or directories that contain
@@ -727,7 +727,7 @@ FILTER_SOURCE_FILES    = NO
 FILTER_SOURCE_PATTERNS =
 
 #---------------------------------------------------------------------------
-# configuration options related to source browsing
+# configuration option related to source browsing
 #---------------------------------------------------------------------------
 
 # If the SOURCE_BROWSER tag is set to YES then a list of source files will
@@ -783,7 +783,7 @@ USE_HTAGS              = NO
 VERBATIM_HEADERS       = YES
 
 #---------------------------------------------------------------------------
-# configuration options related to the alphabetical class index
+# configuration option related to the alphabetical class index
 #---------------------------------------------------------------------------
 
 # If the ALPHABETICAL_INDEX tag is set to YES, an alphabetical index
@@ -806,7 +806,7 @@ COLS_IN_ALPHA_INDEX    = 5
 IGNORE_PREFIX          =
 
 #---------------------------------------------------------------------------
-# configuration options related to the HTML output
+# configuration option related to the HTML output
 #---------------------------------------------------------------------------
 
 # If the GENERATE_HTML tag is set to YES (the default) Doxygen will
@@ -830,7 +830,7 @@ HTML_FILE_EXTENSION    = .html
 # each generated HTML page. If it is left blank doxygen will generate a
 # standard header. Note that when using a custom header you are responsible
 # for the proper inclusion of any scripts and style sheets that doxygen
-# needs, which is dependent on the configuration options used.
+# needs, which is dependent on the configuration option used.
 # It is adviced to generate a default header using "doxygen -w html
 # header.html footer.html stylesheet.css YourConfigFile" and then modify
 # that header. Note that the header is subject to change so you typically
@@ -1154,7 +1154,7 @@ SEARCHENGINE           = YES
 SERVER_BASED_SEARCH    = NO
 
 #---------------------------------------------------------------------------
-# configuration options related to the LaTeX output
+# configuration option related to the LaTeX output
 #---------------------------------------------------------------------------
 
 # If the GENERATE_LATEX tag is set to YES (the default) Doxygen will
@@ -1247,7 +1247,7 @@ LATEX_HIDE_INDICES     = NO
 LATEX_SOURCE_CODE      = NO
 
 #---------------------------------------------------------------------------
-# configuration options related to the RTF output
+# configuration option related to the RTF output
 #---------------------------------------------------------------------------
 
 # If the GENERATE_RTF tag is set to YES Doxygen will generate RTF output
@@ -1289,7 +1289,7 @@ RTF_STYLESHEET_FILE    =
 RTF_EXTENSIONS_FILE    =
 
 #---------------------------------------------------------------------------
-# configuration options related to the man page output
+# configuration option related to the man page output
 #---------------------------------------------------------------------------
 
 # If the GENERATE_MAN tag is set to YES (the default) Doxygen will
@@ -1317,7 +1317,7 @@ MAN_EXTENSION          = .3
 MAN_LINKS              = NO
 
 #---------------------------------------------------------------------------
-# configuration options related to the XML output
+# configuration option related to the XML output
 #---------------------------------------------------------------------------
 
 # If the GENERATE_XML tag is set to YES Doxygen will
@@ -1352,7 +1352,7 @@ XML_DTD                =
 XML_PROGRAMLISTING     = YES
 
 #---------------------------------------------------------------------------
-# configuration options for the AutoGen Definitions output
+# configuration option for the AutoGen Definitions output
 #---------------------------------------------------------------------------
 
 # If the GENERATE_AUTOGEN_DEF tag is set to YES Doxygen will
@@ -1364,7 +1364,7 @@ XML_PROGRAMLISTING     = YES
 GENERATE_AUTOGEN_DEF   = NO
 
 #---------------------------------------------------------------------------
-# configuration options related to the Perl module output
+# configuration option related to the Perl module output
 #---------------------------------------------------------------------------
 
 # If the GENERATE_PERLMOD tag is set to YES Doxygen will
@@ -1399,7 +1399,7 @@ PERLMOD_PRETTY         = YES
 PERLMOD_MAKEVAR_PREFIX =
 
 #---------------------------------------------------------------------------
-# Configuration options related to the preprocessor
+# Configuration option related to the preprocessor
 #---------------------------------------------------------------------------
 
 # If the ENABLE_PREPROCESSING tag is set to YES (the default) Doxygen will
@@ -1510,7 +1510,7 @@ EXTERNAL_GROUPS        = YES
 PERL_PATH              = /usr/bin/perl
 
 #---------------------------------------------------------------------------
-# Configuration options related to the dot tool
+# Configuration option related to the dot tool
 #---------------------------------------------------------------------------
 
 # If the CLASS_DIAGRAMS tag is set to YES (the default) Doxygen will
@@ -1538,7 +1538,7 @@ HIDE_UNDOC_RELATIONS   = YES
 
 # If you set the HAVE_DOT tag to YES then doxygen will assume the dot tool is
 # available from the path. This tool is part of Graphviz, a graph visualization
-# toolkit from AT&T and Lucent Bell Labs. The other options in this section
+# toolkit from AT&T and Lucent Bell Labs. The other option in this section
 # have no effect if this option is set to NO (the default)
 
 HAVE_DOT               = NO
@@ -1617,7 +1617,7 @@ INCLUDE_GRAPH          = YES
 
 INCLUDED_BY_GRAPH      = YES
 
-# If the CALL_GRAPH and HAVE_DOT options are set to YES then
+# If the CALL_GRAPH and HAVE_DOT option are set to YES then
 # doxygen will generate a call dependency graph for every global function
 # or class method. Note that enabling this option will significantly increase
 # the time of a run. So in most cases it will be better to enable call graphs
@@ -1697,7 +1697,7 @@ MAX_DOT_GRAPH_DEPTH    = 0
 DOT_TRANSPARENT        = NO
 
 # Set the DOT_MULTI_TARGETS tag to YES allow dot to generate multiple output
-# files in one run (i.e. multiple -o and -T options on the command line). This
+# files in one run (i.e. multiple -o and -T option on the command line). This
 # makes dot run faster, but since only newer versions of dot (>1.8.10)
 # support this, this feature is disabled by default.
 

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/platforms/cpp/examples/continuous-query-example/config/continuous-query-example.xml
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/examples/continuous-query-example/config/continuous-query-example.xml b/modules/platforms/cpp/examples/continuous-query-example/config/continuous-query-example.xml
index bdc1e92..2febc73 100644
--- a/modules/platforms/cpp/examples/continuous-query-example/config/continuous-query-example.xml
+++ b/modules/platforms/cpp/examples/continuous-query-example/config/continuous-query-example.xml
@@ -32,7 +32,7 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
+                        Ignite provides several option for automatic discovery that can be used
                         instead os static IP based discovery.
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/platforms/cpp/examples/odbc-example/config/example-odbc.xml
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/examples/odbc-example/config/example-odbc.xml b/modules/platforms/cpp/examples/odbc-example/config/example-odbc.xml
index e19075e..ac78937 100644
--- a/modules/platforms/cpp/examples/odbc-example/config/example-odbc.xml
+++ b/modules/platforms/cpp/examples/odbc-example/config/example-odbc.xml
@@ -105,7 +105,7 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
+                        Ignite provides several option for automatic discovery that can be used
                         instead os static IP based discovery.
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/platforms/cpp/examples/putget-example/config/example-cache.xml
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/examples/putget-example/config/example-cache.xml b/modules/platforms/cpp/examples/putget-example/config/example-cache.xml
index 28b726c..b0ed0ff 100644
--- a/modules/platforms/cpp/examples/putget-example/config/example-cache.xml
+++ b/modules/platforms/cpp/examples/putget-example/config/example-cache.xml
@@ -55,7 +55,7 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
+                        Ignite provides several option for automatic discovery that can be used
                         instead os static IP based discovery.
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/platforms/cpp/examples/query-example/config/query-example.xml
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/examples/query-example/config/query-example.xml b/modules/platforms/cpp/examples/query-example/config/query-example.xml
index a7b63c2..9877e1b 100644
--- a/modules/platforms/cpp/examples/query-example/config/query-example.xml
+++ b/modules/platforms/cpp/examples/query-example/config/query-example.xml
@@ -101,7 +101,7 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
+                        Ignite provides several option for automatic discovery that can be used
                         instead os static IP based discovery.
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/platforms/cpp/odbc-test/config/queries-default.xml
----------------------------------------------------------------------
diff --git a/modules/platforms/cpp/odbc-test/config/queries-default.xml b/modules/platforms/cpp/odbc-test/config/queries-default.xml
index c1eaea8..8d28fda 100644
--- a/modules/platforms/cpp/odbc-test/config/queries-default.xml
+++ b/modules/platforms/cpp/odbc-test/config/queries-default.xml
@@ -126,7 +126,7 @@
             <bean class="org.apache.ignite.spi.discovery.tcp.TcpDiscoverySpi">
                 <property name="ipFinder">
                     <!--
-                        Ignite provides several options for automatic discovery that can be used
+                        Ignite provides several option for automatic discovery that can be used
                         instead os static IP based discovery.
                     -->
                     <!-- Uncomment static IP finder to enable static-based discovery of initial nodes. -->

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/platforms/dotnet/Apache.Ignite.Core/IgniteConfigurationSection.xsd
----------------------------------------------------------------------
diff --git a/modules/platforms/dotnet/Apache.Ignite.Core/IgniteConfigurationSection.xsd b/modules/platforms/dotnet/Apache.Ignite.Core/IgniteConfigurationSection.xsd
index 3691aa0..bf69d85 100644
--- a/modules/platforms/dotnet/Apache.Ignite.Core/IgniteConfigurationSection.xsd
+++ b/modules/platforms/dotnet/Apache.Ignite.Core/IgniteConfigurationSection.xsd
@@ -777,7 +777,7 @@
                 </xs:element>
                 <xs:element name="jvmOptions" minOccurs="0">
                     <xs:annotation>
-                        <xs:documentation>Collection of options passed to JVM on Ignite start.</xs:documentation>
+                        <xs:documentation>Collection of option passed to JVM on Ignite start.</xs:documentation>
                     </xs:annotation>
                     <xs:complexType>
                         <xs:sequence>
diff --git a/modules/cassandra/store/src/test/bootstrap/aws/cassandra/cassandra-env.sh b/modules/cassandra/store/src/test/bootstrap/aws/cassandra/cassandra-env.sh
index ba76401..f8583d5 100644
--- a/modules/cassandra/store/src/test/bootstrap/aws/cassandra/cassandra-env.sh
+++ b/modules/cassandra/store/src/test/bootstrap/aws/cassandra/cassandra-env.sh
@@ -167,14 +167,14 @@ JVM_OPTS="$JVM_OPTS -Xloggc:${CASSANDRA_HOME}/logs/gc.log"
 # Here we create the arguments that will get passed to the jvm when
 # starting cassandra.
 
-# Read user-defined JVM options from jvm.options file
-JVM_OPTS_FILE=$CASSANDRA_CONF/jvm.options
+# Read user-defined JVM option from jvm.option file
+JVM_OPTS_FILE=$CASSANDRA_CONF/jvm.option
 for opt in `grep "^-" $JVM_OPTS_FILE`
 do
   JVM_OPTS="$JVM_OPTS $opt"
 done
 
 # Check what parameters were defined on jvm.options file to avoid conflicts
 echo $JVM_OPTS | grep -q Xmn
 DEFINED_XMN=$?
 echo $JVM_OPTS | grep -q Xmx
@@ -184,21 +184,21 @@ DEFINED_XMS=$?
 echo $JVM_OPTS | grep -q UseConcMarkSweepGC
 USING_CMS=$?
 
 # We only set -Xms and -Xmx if they were not defined on jvm.options file
 # If defined, both Xmx and Xms should be defined together.
 if [ $DEFINED_XMX -ne 0 ] && [ $DEFINED_XMS -ne 0 ]; then
      JVM_OPTS="$JVM_OPTS -Xms${MAX_HEAP_SIZE}"
      JVM_OPTS="$JVM_OPTS -Xmx${MAX_HEAP_SIZE}"
 elif [ $DEFINED_XMX -ne 0 ] || [ $DEFINED_XMS -ne 0 ]; then
-     echo "Please set or unset -Xmx and -Xms flags in pairs on jvm.options file."
+     echo "Please set or unset -Xmx and -Xms flags in pairs on jvm.option file."
      exit 1
 fi
 
 # We only set -Xmn flag if it was not defined in jvm.options file
 # and if the CMS GC is being used
 # If defined, both Xmn and Xmx should be defined together.
 if [ $DEFINED_XMN -eq 0 ] && [ $DEFINED_XMX -ne 0 ]; then
-    echo "Please set or unset -Xmx and -Xmn flags in pairs on jvm.options file."
+    echo "Please set or unset -Xmx and -Xmn flags in pairs on jvm.option file."
     exit 1
 elif [ $DEFINED_XMN -ne 0 ] && [ $USING_CMS -eq 0 ]; then
     JVM_OPTS="$JVM_OPTS -Xmn${HEAP_NEWSIZE}"

http://git-wip-us.apache.org/repos/asf/ignite/blob/362700c6/modules/cassandra/store/src/test/bootstrap/aws/cassandra/cassandra-template.yaml
----------------------------------------------------------------------
@@ -167,14 +167,14 @@ JVM_OPTS="$JVM_OPTS -Xloggc:${CASSANDRA_HOME}/logs/gc.log"
 done
 
-# Check what parameters were defined on jvm.options file to avoid conflicts
+# Check what parameters were defined on jvm.option file to avoid conflicts
 echo $JVM_OPTS | grep -q Xmn
 DEFINED_XMN=$?
@@ -184,21 +184,21 @@ DEFINED_XMS=$?
 USING_CMS=$?
 
-# We only set -Xms and -Xmx if they were not defined on jvm.options file
+# We only set -Xms and -Xmx if they were not defined on jvm.option file
 # If defined, both Xmx and Xms should be defined together.
 if [ $DEFINED_XMX -ne 0 ] && [ $DEFINED_XMS -ne 0 ]; then
@@ -184,21 +184,21 @@ DEFINED_XMS=$?
 fi
 
-# We only set -Xmn flag if it was not defined in jvm.options file
+# We only set -Xmn flag if it was not defined in jvm.option file
 # and if the CMS GC is being used
 # If defined, both Xmn and Xmx should be defined together.